module Admin::PersonalProjectsHelper

	def get_paper_list
		user = current_user.nil? ? OrbitHelper.current_user : current_user
	  user_profile = user.member_profile
	  projects = Project.where(:member_profile_id => user_profile.id)
	  projects = projects.collect do |p|
	      files = p.project_files.collect do |pf|
	          {
	              "title" => pf.title,
	              "description" => pf.description,
	              "link" => pf.file.url,
	              "extension" => (pf.file.url.split(".").last rescue "")
	          }
	      end

	      {
	          "id" => p.id.to_s,
	          "edit_url" => "/#{I18n.locale.to_s}/admin/members/#{user_profile.to_param}/projects/#{p.to_param}/edit",
	          "delete_url" => "/#{I18n.locale.to_s}/admin/projects/#{p.id.to_s}",
	          "paper_title" => p.project_title,
	          "keywords" => p.keywords,
	          "abstract" => p.abstract,
	          "files" => files
	      }
	  end
	  projects
	end

	def import_this_project(row, mp)
		value = nil
	  	project = Project.new
	  	row.cells.each_with_index do |cell,index|
	  		next if index < 2
	  		next if cell.nil?
	  		val = cell.value
	  		next if val.nil? || val == ""
	  		case index
	  		when 2
	  			value = {"en" => val}
	  		when 3
	  			begin
	  				value["zh_tw"] = val 
	  			rescue 
	  				value = {"zh_tw" => val}
	  			end
	  			project.project_title_translations = value
	  		when 4
	  			value = {"en" => val}
	  		when 5
	  			begin
	  				value["zh_tw"] = val 
	  			rescue 
	  				value = {"zh_tw" => val}
	  			end
	  			project.job_title_translations = value
	  		when 6
	  			value = {"en" => val}
	  		when 7
	  			begin
	  				value["zh_tw"] = val 
	  			rescue 
	  				value = {"zh_tw" => val}
	  			end
	  			project.participator_translations = value
	  		when 8
	  			value = {"en" => val}
	  		when 9
	  			begin
	  				value["zh_tw"] = val 
	  			rescue 
	  				value = {"zh_tw" => val}
	  			end
	  			project.unit_translations = value
	  		when 10
	  			project.year = val
	  		when 11
	  			project.language = val
	  		when 12
	  			pts = ProjectType.asc(:created_at).all.to_a
  				project.project_type = pts[val.to_i] if val.to_s.is_i? && val.to_i < pts.count
	  		when 13
	  			project.period_start_date = val
	  		when 14
	  			project.period_end_date = val
	  		when 15
	  			project.url = val
	  		when 16
	  			project.keywords = val
	  		when 17
	  			project.abstract = val
	  		when 18
	  			project.note = val
	  		end
	  	end
	  	project.member_profile = mp
	  	project.save
	end

	def get_data_for_excel(year_start,year_end)
	    data = []
	    roles = Role.where(:disabled => false, :title.ne => "", :title.ne => nil).asc(:key)
	    roles.each do |role|
	      d = {}
	      d["name"] = role.title
	      mps = role.member_profile_ids
	      # d1 = DateTime.new(year_start,1,1,0,0)
	      # d2 = DateTime.new(year_end,12,31,23,59)   
	      d["data"] = Project.where(:year.gte => year_start, :year.lte => year_end, :member_profile_id.in => mps) rescue []
	      data << d
	    end
	    return data
	end

  	def get_chart_data(year_start,year_end,role,type)
	    case type
	    when "category"
	      jls = ProjectType.all
	    end

	    finaldata = []
	    role = Role.find(role) rescue nil
	    mps = []
	    if !role.nil?
	       mps = role.member_profile_ids
	    end
	    jls.each do |jl|
	      data = {}
	      data["name"] = jl.title
	      data["data"] = {}
	      (year_start..year_end).each do |year|
	        # d1 = DateTime.new(year,1,1,0,0)
	        # d2 = DateTime.new(year,12,31,23,59)   
	        t = jl.projects.where(:year => year.to_s, :member_profile_id.in => mps).count rescue 0
	        data["data"][year.to_s] = t
	      end
	      finaldata << data
	    end
	    data = {"name" => "N/A", "data" => {}}
	    (year_start..year_end).each do |year|
	      # d1 = DateTime.new(year,1,1,0,0)
	      # d2 = DateTime.new(year,12,31,23,59)
	      case type
	      when "category"
	         t = Project.where(:year => year, :member_profile_id.in => mps, :project_type_id => nil).count rescue 0
	      end
	     
	      data["data"][year.to_s] = t
	    end
	    finaldata << data
	    finaldata
	 end
end